#!/bin/bash
#
# stalCreateReport
#

UID2=$(id -u)

if [ "$UID2" != "0" ]; then
    echo "need root access"
    exit
fi

todayLog=$(LC_TIME=C date +"%b %e")
reportSuffix=$(date +%Y%m%d_%H%M)

reportDir=/var/tmp/stal_report
mkdir -p $reportDir/{termidesk,users}

reportDirTar=/var/tmp/stal_report_${reportSuffix}.tgz

if [ ! -d $reportDir ]; then
    echo "create $reportDir failed"
fi

# stal logs
for f in /var/log/termidesk/*.log; do
    #grep $todayLog $f > $reportDir/termidesk/$f
    cp $f $reportDir/termidesk > /dev/null 2>&1
done

# parse users logs
grep username /var/log/termidesk/stal_service.log | awk 'match($0, /username:[[:space:]]*([^,]+)/, arr) { print arr[1] }' | sort | uniq | while read user; do
    mkdir $reportDir/users/$user
    id $user > $reportDir/users/$user/id
    pdpl-user $user > $reportDir/users/$user/pdpl-user

    homedir=$(getent passwd $user | cut -d ":" -f6)
    if [ -z "$homedir" ]; then
        if [ -d /home/$user ]; then
            homedir=/home/$user
        fi
    fi

    if [ -d "$homedir" ]; then
        if [ -d $homedir/.stal ]; then
	    cp $homedir/.stal/* $reportDir/users/$user > /dev/null 2>&1
        fi
        if [ -d $homedir/.local/share/xorg ]; then
	    cp -r $homedir/.local/share/xorg $reportDir/users/$user > /dev/null 2>&1
        fi
    else
	echo > $reportDir/users/$user/home_not_found > /dev/null 2>&1
    fi
done

# sessions
(
    dbus-send --dest=ru.uveon.stal --system --print-reply --type=method_call  /ru/uveon/stal ru.uveon.stal.stalSessions | awk '/uint32/ { print $2 }' |
    while read sid; do
        if [ -n "$sid" ]; then
            echo "session id: $sid =>"
            dbus-send --dest=ru.uveon.stal --system --print-reply=literal --type=method_call  /ru/uveon/stal ru.uveon.stal.stalSessionInfoJson uint32:$sid
            echo -e "\n"
        fi
    done
) > $reportDir/sessions.log

# stal-proxy
user=stal-proxy
homedir=$(getent passwd | grep $user | cut -d ":" -f6)
mkdir $reportDir/users/$user
if [ -d $homedir/.stal ]; then
    cp $homedir/.stal/* $reportDir/users/$user > /dev/null 2>&1
fi

# system logs
uname -a > $reportDir/uname.log
hostnamectl > $reportDir/hostname.log
sysctl -a > $reportDir/sysctl.log
free > $reportDir/free.log
df -h > $reportDir/df.log
lsblk > $reportDir/lsblk.log
dmesg > $reportDir/dmesg.log
cat /var/log/syslog > $reportDir/syslog.log
cat /var/log/auth.log > $reportDir/auth.log
ps aufx > $reportDir/ps.log
netstat -anpt > $reportDir/netstat.log
journalctl -p 3 -x --until=00:00:00 > $reportDir/errors.log
[ -f /var/log/cups/error_logs ] && cat /var/log/cups/error_logs > $reportDir/cups_err.log
[ -f /etc/parsec/parsec.conf ] && cat /etc/parsec/parsec.conf > $reportDir/parsec.conf
systemctl status termidesk-stal > $reportDir/termidesk-stal.status
systemctl status stal-proxy > $reportDir/stal-proxy.status

# astra info
(
    echo -n "astra-version: "
    cat /etc/astra/build_version

    echo -n "astra-modeswitch: "
    astra-modeswitch getname

    echo -n "astra-mac-control: "
    astra-mac-control status

    echo -n "astra-mic-control: "
    astra-mic-control status
) > $reportDir/astralinux.log

tar czf $reportDirTar $reportDir
rm -rf $reportDir

echo $reportDirTar
